{% extends 'toga/base.html' %}
{% block title %}{{ app.main_window.title }}{% endblock %}
{% block bytecode %}
        <script
            id="batavia-toga"
            type="application/python-bytecode"
            data-filename="toga/__init__.py">
{{ toga }}
        </script>
    {% for name, payload in widgets.items %}
        <script
            id="batavia-{{ name }}"
            type="application/python-bytecode"
            data-filename="{{ payload.filename }}.py">
{{ payload.bytecode }}
        </script>
    {% endfor %}
        <script
            id="batavia-bootstrap"
            type="application/python-bytecode"
            data-filename="bootstrap.py">
{{ bootstrap }}
        </script>
    {% for name, payload in callbacks.items %}
        <script
            id="batavia-{{ name }}"
            type="application/python-bytecode"
            data-filename="{{ payload.filename }}.py">
{{ payload.bytecode }}
        </script>
    {% endfor %}
{% endblock %}
{% block content %}
        {{ app }}
        <script>
        {% for window in app.windows %}
            window.open('${{ window.id }}/', '_blank', 'location=yes,height={{ window.width }},width={{ window.height }},scrollbars=yes,status=no');
        {% endfor %}
        </script>
{% endblock %}
